@@ -49,9 +49,11 @@ class BaseChart():
         'family_shape': 0,
         'individual_photo_active': False,
         'individual_photo_relative_size': 2.5,
+        'individual_photo_relative_distance': 1.1,
         'debug_visualize_connections': False,
         'debug_visualize_ambiguous_placement': False,
-        'coloring_of_individuals': 'unique'
+        'coloring_of_individuals': 'unique',
+        'line_weighting': 'none'
     }
     DEFAULT_POSITIONING = {
         'unique_graphical_representation': True
@@ -60,6 +62,22 @@ class BaseChart():
     }
     SETTINGS_DESCRIPTION = _strings
 
+    COLOR_CONFIGURATIONS = {
+        'light': {
+            'descendant_chart_marriage_lines': (0, 0, 0),
+            'fade_to_death': (0, 0, 0),
+            'grid_line': (210, 210, 210),
+            'text_label': (0, 0, 0)
+        },
+        'dark': {
+            'descendant_chart_marriage_lines': (200, 200, 200),
+            'fade_to_death': (255, 255, 255),
+            'grid_line': (20, 20, 20),
+            'text_label': (200, 200, 200)
+        }
+    }
+    _colors = COLOR_CONFIGURATIONS['light']
+
     # TODO: extract base class for other chart types
     _graphical_family_class = GraphicalFamily
     # TODO: extract base class for other chart types
@@ -339,6 +357,7 @@ class BaseChart():
                     return True
             return False
 
+        line_bend_orientation = 0 if (str(type(self)) == "<class 'life_line_chart.DescendantChart.DescendantChart'>" and self._positioning['chart_layout'] == 'cactus') else 1
         # assign the individuals to all x_indices in which they appear
         for gr_individual in self.gr_individuals:
             position_vector = list(gr_individual.get_position_dict().values())
@@ -351,7 +370,10 @@ class BaseChart():
                     spouse_families = [(None, None, None, None)] * missing_families
 
             for i, value in enumerate(position_vector):
-                x_index = value[1]
+                if line_bend_orientation == 1:
+                    x_index = value[1]
+                else:
+                    x_index = position_vector[1][1]
                 marriage = spouse_families[i][2]
                 if x_index not in v:
                     v[x_index] = []
@@ -517,7 +539,7 @@ class BaseChart():
             float: difference of ordinal value
         """
         display_factor = 1 if self._formatting['flip_vertically'] else -1
-        return delta_y / (self._formatting['total_height'] * display_factor) * (self.max_ordinal-self.min_ordinal)
+        return delta_y / (self._formatting['total_height'] * display_factor) * (self.chart_max_ordinal-self.chart_min_ordinal)
 
     def _inverse_y_position(self, pos_y):
         """
@@ -600,3 +622,59 @@ class BaseChart():
         for _, instance in self._instances.items():
             if instance is not None:
                 instance.graphical_representations.clear()
+
+    def get_filtered_photos(self, birth_ordinal_value, original_images):
+        images = {}
+        photo_width = self._formatting['relative_line_thickness'] * self._formatting['individual_photo_relative_size'] * self._formatting['horizontal_step_size'] # * (1 + self.max_x_index - self.min_x_index)
+        photo_height = photo_width * self._formatting['individual_photo_relative_distance']
+        photo_ov_height = abs(self._inverse_y_delta(photo_height))
+        ov_list = list(original_images.keys())
+        settings_list = list(original_images.values())
+        if len(original_images) > 0:
+            max_ordinal = max(list(original_images.keys()))
+        else:
+            max_ordinal = -1
+        latest_ordinal = birth_ordinal_value - photo_ov_height
+
+        closest_index = -1
+        used_indices_list = []
+        while closest_index < len(ov_list) and latest_ordinal < max_ordinal:
+            offset_ov_list = [(abs(v - latest_ordinal), i) for i, v in enumerate(ov_list) if i not in used_indices_list and v > latest_ordinal]
+            if not offset_ov_list:
+                break
+            offset_ov_list.sort()
+            closest_index = offset_ov_list[0][1]
+            used_indices_list.append(closest_index)
+            settings = settings_list[closest_index]
+            exact_ordinal_value = ov_list[closest_index]
+            relative_photo_height = min(1, settings['size'][1] / settings['size'][0])
+            current_ordinal = max(latest_ordinal + 0.5*photo_ov_height*relative_photo_height, exact_ordinal_value)
+            images[current_ordinal] = settings
+            latest_ordinal = current_ordinal + 0.5*photo_ov_height*relative_photo_height
+        # for ordinal_value, settings in sorted(original_images.items()):
+        #     # filename = settings['filename']
+        #     if len(images) > 0:
+        #         max_ordinal = max(list(images.keys()))
+        #     else:
+        #         max_ordinal = -1
+        #     if round((ordinal_value-birth_ordinal_value)/image_step_size) > round((max_ordinal-birth_ordinal_value)/image_step_size):
+        #         images[birth_ordinal_value + round((ordinal_value-birth_ordinal_value)/image_step_size)
+        #                 * image_step_size] = settings
+        return images
+
+    def get_filtered_photos_raster(self, birth_ordinal_value, original_images):
+        images = {}
+        photo_width = self._formatting['relative_line_thickness'] * self._formatting['individual_photo_relative_size'] * self._formatting['horizontal_step_size'] # * (1 + self.max_x_index - self.min_x_index)
+        photo_height = photo_width * self._formatting['individual_photo_relative_distance']
+        photo_ov_height = abs(self._inverse_y_delta(photo_height))
+        image_step_size = photo_ov_height
+        for ordinal_value, settings in sorted(original_images.items()):
+            # filename = settings['filename']
+            if len(images) > 0:
+                max_ordinal = max(list(images.keys()))
+            else:
+                max_ordinal = -1
+            if round((ordinal_value-birth_ordinal_value)/image_step_size) > round((max_ordinal-birth_ordinal_value)/image_step_size):
+                images[birth_ordinal_value + round((ordinal_value-birth_ordinal_value)/image_step_size)
+                        * image_step_size] = settings
+        return images
