@@ -19,7 +19,8 @@ def estimate_death_date(individual):
             'tag_name': 'None',
             'date': date,
             'ordinal_value': date.toordinal(),
-            'comment': f'Estimated (max age {max_age})'
+            'comment': f'Estimated (max age {max_age})',
+            'precision': 'y'
         }
         if date > datetime.datetime.now():
             individual.events['death_or_burial']['date'] = datetime.datetime.now()
@@ -43,7 +44,7 @@ def estimate_birth_date(individual, instances):
         # parents marriage
         for family_id in individual.child_of_family_id:
             parents_marriage = instances[('f', family_id)]
-            if parents_marriage.marriage:
+            if parents_marriage and parents_marriage.marriage:
                 if not individual.events['birth_or_christening'] or individual.events['birth_or_christening']['ordinal_value'] < parents_marriage.marriage['ordinal_value']:
                     if individual.events['birth_or_christening'] and individual.events['birth_or_christening']['ordinal_value'] < parents_marriage.marriage['ordinal_value']:
                         date = deepcopy(parents_marriage.marriage['date'])
@@ -55,7 +56,8 @@ def estimate_birth_date(individual, instances):
                         'tag_name': 'MARR',
                         'comment': 'Estimated (min 1 after parents marriage)',
                         'date': date,
-                        'ordinal_value': date.toordinal()
+                        'ordinal_value': date.toordinal(),
+                        'precision': 'y'
                     }
         if individual.events['birth_or_christening']:
             date = individual.events['birth_or_christening']['date']
@@ -78,7 +80,8 @@ def estimate_birth_date(individual, instances):
                         'tag_name': 'MARR',
                         'comment': 'Estimated (min 25 at marriage)',
                         'date': date,
-                        'ordinal_value': date.toordinal()
+                        'ordinal_value': date.toordinal(),
+                        'precision': 'y'
                     }
         if individual.events['birth_or_christening'] and individual.events['birth_or_christening']['date'].year > 25:
             date = individual.events['birth_or_christening']['date']
@@ -94,7 +97,8 @@ def estimate_birth_date(individual, instances):
                 'tag_name': 'None',
                 'date': date,
                 'ordinal_value': date.toordinal(),
-                'comment': 'Estimated (max age 75)'
+                'comment': 'Estimated (max age 75)',
+                'precision': 'y'
             }
 
 
@@ -102,6 +106,10 @@ class BaseIndividual():
     """
     Base class for individuals. This class is used as interface to the database.
     """
+    # ordinal value of the birth date
+    __birth_date_ov = None
+    # ordinal value of the death date
+    __death_date_ov = None
 
     def __init__(self, instances, individual_id):
         self._instances = instances
@@ -118,15 +126,14 @@ class BaseIndividual():
 
     def _initialize(self):
         self._marriage_family_ids = self._get_marriage_family_ids()
-        unsorted_marriages = [
-            self._instances[('f', m)] for m in self._marriage_family_ids]
-        sorted_pairs = zip([(m.marriage['ordinal_value'], i) if m.marriage else (
-            0, i) for i, m in enumerate(unsorted_marriages)], unsorted_marriages)
-        self.marriages = [m for ov, m in sorted(sorted_pairs)]
+        self.marriages = [
+            self._instances[('f', m)] for m in self._marriage_family_ids
+            if self._instances[('f', m)]]
+        self.marriages.sort()
 
     def __lt__(self, other):
         """
-        Sorting by name
+        Sorting by birth date
 
         Args:
             other (BaseIndividual): the other instance
@@ -134,7 +141,7 @@ class BaseIndividual():
         Returns:
             bool: is less than
         """
-        return self.plain_name < other.plain_name
+        return self.birth_date_ov < other.birth_date_ov
 
     def get_name(self):
         if True:
@@ -162,6 +169,23 @@ class BaseIndividual():
     def birth_date(self):
         return self._instances.display_birth_date(self)
 
+    @property
+    def birth_date_ov(self):
+        """
+        get the ordinal value of the birth (or christening or baptism) date
+
+        Returns:
+            float: ordinal value of birth date
+        """
+        if self.__birth_date_ov is None:
+            boc = self.events.get('birth_or_christening')
+            if boc:
+                self.__birth_date_ov = boc['ordinal_value']
+                return self.__birth_date_ov
+            return None
+        else:
+            return self.__birth_date_ov
+
     @property
     def birth_label(self):
         """
@@ -204,6 +228,23 @@ class BaseIndividual():
     def death_date(self):
         return self._instances.display_death_date(self)
 
+    @property
+    def death_date_ov(self):
+        """
+        get the ordinal value of the death (or burial) date
+
+        Returns:
+            float: ordinal value of death date
+        """
+        if self.__death_date_ov is None:
+            dob = self.events.get('death_or_burial')
+            if dob:
+                self.__death_date_ov = dob['ordinal_value']
+                return self.__death_date_ov
+            return None
+        else:
+            return self.__death_date_ov
+
     @property
     def info_text(self):
         return self._instances.display_info_text(self)
@@ -217,7 +258,9 @@ class BaseIndividual():
 
     @property
     def child_of_families(self):
-        return [self._instances[('f', family_id)] for family_id in self.child_of_family_id]
+        families = [self._instances[('f', family_id)] for family_id in self.child_of_family_id
+            if self._instances[('f', family_id)]]
+        return families
 
     def has_graphical_representation(self):
         return len(self.graphical_representations) > 0
