@@ -9,6 +9,7 @@ from math import floor, ceil, pi, e
 from .SimpleSVGItems import Line, Path, CubicBezier
 from .Exceptions import LifeLineChartCannotMoveIndividual, LifeLineChartCollisionDetected
 from .BaseChart import BaseChart
+from .IntermediateGraphicalItems import new_text_item, new_image_item, new_path_item
 
 logger = logging.getLogger("life_line_chart")
 
@@ -162,9 +163,9 @@ class BaseSVGChart(BaseChart):
 
         self.additional_graphical_items.clear()
 
-        font_size = self._formatting['font_size_description'] * \
-            self._formatting['relative_line_thickness'] * \
+        line_thickness = self._formatting['relative_line_thickness'] * \
             self._formatting['horizontal_step_size']
+        font_size = self._formatting['font_size_description'] * line_thickness
 
         if len(self.gr_individuals) == 0:
             # settings for empty graphs
@@ -193,34 +194,30 @@ class BaseSVGChart(BaseChart):
                 datetime.date(year, 1, 1).toordinal())
             if year % 10 == 0:
                 # add bold line and number every 10 years
-                self.additional_graphical_items['grid'].append({
-                    'type': 'path',
-                            'config': {'type': 'Line', 'arguments': (0 + year_pos*1j, self.get_full_width() + year_pos*1j)},
-                            'color': [210]*3,
-                            'stroke_width': 1
-                }
+                self.additional_graphical_items['grid'].append(
+                    new_path_item(
+                        self, 'Line',
+                        (0 + year_pos*1j, self.get_full_width() + year_pos*1j),
+                        self._colors['grid_line'], 1
+                    )
                 )
-                self.additional_graphical_items['axis'].append({
-                    'type': 'text',
-                            'config': {
-                                'style': f"font-size:{font_size}px;font-family:{self._formatting['font_name']}",
-                                'text': str(year),
-                                'text-anchor': 'end',
-                                # 'align' : 'center',
-                                'insert': (self.get_full_width() - self._formatting['horizontal_step_size']*0.01, year_pos),
-                            },
-                    'font_size': font_size,
-                    'font_name': self._formatting['font_name'],
-                }
+                self.additional_graphical_items['axis'].append(
+                    new_text_item(
+                        self=self,
+                        text=str(year),
+                        pos_x=self.get_full_width() - self._formatting['horizontal_step_size']*0.01,
+                        pos_y=year_pos,
+                        text_anchor='end',
+                    )
                 )
             else:
                 # add thin line
-                self.additional_graphical_items['grid'].append({
-                    'type': 'path',
-                            'config': {'type': 'Line', 'arguments': (0 + year_pos*1j, self.get_full_width() + year_pos*1j)},
-                            'color': [210]*3,
-                            'stroke_width': 0.1
-                }
+                self.additional_graphical_items['grid'].append(
+                    new_path_item(
+                        self, 'Line',
+                        (0 + year_pos*1j, self.get_full_width() + year_pos*1j),
+                        self._colors['grid_line'], 0.1
+                    )
                 )
 
         min_x_index = 9e99
@@ -239,6 +236,9 @@ class BaseSVGChart(BaseChart):
         self.min_x_index = min_x_index  # -1000
         self.max_x_index = max_x_index + 1  # +200
 
+        cactus_chart = (str(type(self)) == "<class 'life_line_chart.DescendantChart.DescendantChart'>" and self._positioning['chart_layout'] == 'cactus')
+        line_bend_orientation = 0 if cactus_chart else 1
+
         for gr_individual in self.gr_individuals:
             debug_items = []
             birth_date_ov = gr_individual.birth_date_ov
@@ -264,9 +264,20 @@ class BaseSVGChart(BaseChart):
             marriage_is_crossconnected = []
             new_x_indices_after_marriage = []
             marriage_labels = []
+
+            def coordinate_transformation(x, y):
+                new_x, new_y = self._map_position(x, y)
+                return new_x + new_y*1j
             def calculate_ring_position(gr_family):
                 h_pos = gr_family.gr_husb.get_position_dict(gr_family) if gr_family.gr_husb else None
                 w_pos = gr_family.gr_wife.get_position_dict(gr_family) if gr_family.gr_wife else None
+                if (str(type(self)) == "<class 'life_line_chart.DescendantChart.DescendantChart'>" and self._positioning['chart_layout'] == 'cactus'):
+                    if h_pos and not w_pos:
+                        return (h_pos[1],
+                            gr_family.marriage['ordinal_value'])
+                    if w_pos and not h_pos:
+                        return (w_pos[1],
+                            gr_family.marriage['ordinal_value'])
                 if h_pos is None or w_pos is None:
                     vcs = gr_family.visible_children
                     if vcs:
@@ -338,9 +349,6 @@ class BaseSVGChart(BaseChart):
                         else:
                             thickness = 0.5*self._formatting['horizontal_step_size']*1
                             color = (25, 25, 25)
-                        def coordinate_transformation(x, y):
-                            new_x, new_y = self._map_position(x, y)
-                            return new_x + new_y*1j
                         l_i = gr_individual
                         x_p_list = list(l_i.get_position_dict().values())
                         x_p = x_p_list[0][1]
@@ -350,19 +358,17 @@ class BaseSVGChart(BaseChart):
                                 new_marriage_ordinal = min(l_i.birth_date_ov-5*365, marriage_ordinal)
                             else:
                                 new_marriage_ordinal = max(l_i.birth_date_ov, marriage_ordinal+5*365)
-                        debug_items.append(((99, 'layer_debug'),
-                                {
-                                'type': 'path',
-                                'config': {'type': 'Line', 'arguments': (
-                                        coordinate_transformation(
+                        debug_items.append((
+                            (99, 'layer_debug'),
+                            new_path_item(
+                                self, 'Line',
+                                points=[coordinate_transformation(
                                             marriage_ring_index, new_marriage_ordinal),
                                         coordinate_transformation(
-                                            x_p, l_i.birth_date_ov)
-                                    )},
-                                'color': color,
-                                'stroke_width': thickness
-                                }
-                            ))
+                                            x_p, l_i.birth_date_ov)],
+                                color=color, stroke_width=thickness
+                            )
+                        ))
 
             # generate event node information
             knots = []
@@ -373,54 +379,69 @@ class BaseSVGChart(BaseChart):
             _birth_position = self._map_position(*_birth_original_location)
             _death_position = self._map_position(*_death_original_location)
             knots.append((x_pos_list[0][1], birth_date_ov, None))
-            images = []
             for index, ((marriage_ring_index, marriage_ordinal), new_x_index_after_marriage, label, gr_family, has_ring, is_cross_connected) in enumerate(zip(marriage_ring_positions, new_x_indices_after_marriage, marriage_labels, marriage_families, marriage_has_ring, marriage_is_crossconnected)):
+                if cactus_chart:
+                    spouse_index =  (new_x_index_after_marriage-marriage_ring_index)*(-1) + marriage_ring_index
+                    marriage_ring_index = new_x_index_after_marriage
+                    if spouse_index != marriage_ring_index:
+                        stroke_width = line_thickness*0.1
+                        if has_ring:
+                            gr_individual.items.append((
+                                (0, 'layer_marriage_connections'),
+                                new_path_item(
+                                    self, 'Line',
+                                    (coordinate_transformation(
+                                        spouse_index, marriage_ordinal),
+                                    coordinate_transformation(
+                                        marriage_ring_index, marriage_ordinal)),
+                                    self._colors['descendant_chart_marriage_lines'],
+                                    stroke_width,
+                                    stroke_dasharray=f"{stroke_width*5},{stroke_width*5}",
+                                )
+                            ))
+                        has_ring = True
                 if not self._formatting['no_ring'] and has_ring:
                     ring_position = self._map_position(
                         marriage_ring_index, marriage_ordinal)
-                    images.append(((2, 'layer_ring_image'), {
-                            'type': 'image',
-                            'config': {
-                                'insert': (
-                                    ring_position[0] - self._formatting['relative_line_thickness'] *
-                                    self._formatting['horizontal_step_size']*1,
-                                    ring_position[1] - self._formatting['relative_line_thickness']*self._formatting['horizontal_step_size']*1),
-                                'size': (
-                                    self._formatting['relative_line_thickness'] *
-                                    self._formatting['horizontal_step_size']*2,
-                                    self._formatting['relative_line_thickness']*self._formatting['horizontal_step_size']*2),
-                            },
-                            'filename': os.path.join(os.path.dirname(__file__), "ringe.png"),
-                            'size': (119,75),
-                            'gir':gr_individual,
-                            'gfr':gr_family
-                        }
+                    gr_individual.items.append((
+                        (2, 'layer_ring_image'),
+                        new_image_item(
+                            self=self,
+                            pos_x = ring_position[0] - line_thickness*1,
+                            pos_y = ring_position[1] - line_thickness*1,
+                            size_x = line_thickness*2,
+                            size_y = line_thickness*2,
+                            filename = os.path.join(os.path.dirname(__file__), "ringe.png"),
+                            original_size = (119,75),
+                            gir = gr_individual,
+                            gfr = gr_family
+                        )
                     ))
                 if self._formatting['marriage_label_active']:
                     dy_line = self._inverse_y_position(
-                        self._formatting['relative_line_thickness']*self._formatting['horizontal_step_size']) - self._inverse_y_position(0)
+                        line_thickness) - self._inverse_y_position(0)
                     for index2, line in enumerate(label.split('\n')):
                         position = self._map_position(
                             marriage_ring_index, marriage_ordinal + dy_line)
-                        position = (position[0], position[1] +
-                                    (index2 + 0.2) * font_size * 1.2)
-                        images.append(((5, 'layer_marriage_label'), {
-                            'type': 'text',
-                            'config': {
-                                    'style': f"font-size:{font_size}px;font-family:{self._formatting['font_name']}",
-                                    'text': line,
-                                    'text-anchor': 'middle',
-                                    # 'align' : 'center',
-                                    'insert': position,
-                            },
-                            'font_size': font_size,
-                            'font_name': self._formatting['font_name'],
-                        }))
-                knots.append((marriage_ring_index, marriage_ordinal, is_cross_connected))
-                if index + 1 < len(marriage_ordinals):
-                    # zwischenpunkt zur ursprungsposition
-                    knots.append(
-                        (new_x_index_after_marriage, marriage_ordinals[index]/2+marriage_ordinals[index+1]/2, False))
+                        gr_individual.items.append((
+                            (5, 'layer_marriage_label'),
+                            new_text_item(
+                                self=self,
+                                text=line,
+                                pos_x=position[0],
+                                pos_y=position[1] + (index2 + 0.2)*font_size*1.2,
+                            )
+                        ))
+
+                if cactus_chart:
+                    if index == 0:
+                        knots.append((new_x_index_after_marriage, marriage_ordinal, False))
+                else:
+                    knots.append((marriage_ring_index, marriage_ordinal, is_cross_connected))
+                    if index + 1 < len(marriage_ordinals):
+                        # zwischenpunkt zur ursprungsposition
+                        knots.append(
+                            (new_x_index_after_marriage, marriage_ordinals[index]/2+marriage_ordinals[index+1]/2, False))
             knots.append((x_pos_list[-1][1], death_event['ordinal_value'], False))
 
             Path_types = {
@@ -429,7 +450,7 @@ class BaseSVGChart(BaseChart):
             }
 
             # generate spline paths
-            def marriage_bezier(images, data, knots, flip=False):
+            def marriage_bezier(data, knots, flip=False):
                 """
                 Tranlate event information to bezier splines.
 
@@ -438,14 +459,15 @@ class BaseSVGChart(BaseChart):
                     knots (list): list of event nodes
                     flip (bool, optional): flip shape of the spline. Defaults to False.
                 """
-                def coordinate_transformation(x, y):
-                    new_x, new_y = self._map_position(x, y)
-                    return new_x + new_y*1j
                 if flip:
                     t = 1
                 else:
                     t = 0
-                if len(knots) == 2:
+
+                if self._formatting['individual_photo_active'] and len(gr_individual.individual.images) > 0:
+                    photo_dict = self.get_filtered_photos(birth_date_ov, gr_individual.individual.images)
+
+                if len(knots) == 2 and ('chart_layout' not in self._positioning or self._positioning['chart_layout'] != 'cactus'):
                     data.append(
                         ({'type': 'Line', 'arguments': (
                             coordinate_transformation(
@@ -462,13 +484,12 @@ class BaseSVGChart(BaseChart):
                         index = 0
                         svg_path = Path_types[data[-1][0]
                                               ['type']](*data[-1][0]['arguments'])
-                        for ov, image_dict in gr_individual.individual.images.items():
+                        for ov, image_dict in photo_dict.items():
                             image_filename = image_dict['filename']
                             image_size = image_dict['size']
                             if ov >= knots[index][1] and ov <= knots[index + 1][1]:
                                 photo_size = self._formatting['individual_photo_relative_size'] * \
-                                    self._formatting['relative_line_thickness'] * \
-                                    self._formatting['horizontal_step_size']
+                                    line_thickness
                                 if type(svg_path) == Line:
                                     xpos = svg_path.start.real + \
                                         self._map_y_position(ov)*1j
@@ -477,65 +498,58 @@ class BaseSVGChart(BaseChart):
                                     root = intersection_polynomial(coeffs, self._map_y_position(ov))
                                     xpos = svg_path.point(root)
 
-                                images.append(((4, 'layer_photos'), {
-                                        'type': 'image',
-                                        'config': {
-                                                'insert': (
-                                                    xpos.real - photo_size/2,
-                                                    xpos.imag - photo_size/2),
-                                                'size': (photo_size, photo_size),
-                                        },
-                                        'filename': image_filename,
-                                        'size': image_size
-                                    }
+                                gr_individual.items.append((
+                                    (4, 'layer_photos'),
+                                    new_image_item(
+                                        self=self,
+                                        pos_x = xpos.real - photo_size/2,
+                                        pos_y = xpos.imag - photo_size/2,
+                                        size_x = photo_size,
+                                        size_y = photo_size,
+                                        filename = image_filename,
+                                        original_size = image_size
+                                    )
                                 ))
                 else:
+                    # self._formatting['family_shape'] = 2
                     for index in range(len(knots)-1):
                         def interp(*val):
+                            if (index + t) % 2 == line_bend_orientation:
+                                val = [val[1], val[0]]
                             return (knots[index][0]*(1-val[0]) + knots[index+1][0]*val[0],
                                     knots[index][1]*(1-val[1]) + knots[index+1][1]*val[1])
-                        if (index + t) % 2 == 0:
-                            data.append(
-                                ({'type': 'CubicBezier', 'arguments': (
-                                    coordinate_transformation(*interp(0, 0)),
-                                    coordinate_transformation(
-                                        *interp(0, 1)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(0.0, 0.7)),
-                                    coordinate_transformation(
-                                        *interp(0, 1)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(0.5, 0.9)),
-                                    coordinate_transformation(*interp(1, 1)),
-                                )},
-                                    (_birth_position[1], self._map_y_position(
-                                        self._formatting['fade_individual_color_black_age']*365+birth_date_ov)),
-                                # connection to this knot is relevant
-                                knots[index+1][2]# and index + 1 < len(knots) or knots[index + 1][2]
-                                )
-                            )
-                        else:
-                            data.append(
-                                ({'type': 'CubicBezier', 'arguments': (
-                                    coordinate_transformation(*interp(0, 0)),
-                                    coordinate_transformation(
-                                        *interp(1, 0)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(0.8, 0)),
-                                    coordinate_transformation(
-                                        *interp(1, 0)) if self._formatting['family_shape'] == 0 else coordinate_transformation(*interp(1, 0.2)),
-                                    coordinate_transformation(*interp(1, 1)),
-                                )},
-                                    (_birth_position[1], self._map_y_position(
-                                        self._formatting['fade_individual_color_black_age']*365+birth_date_ov)),
-                                # connection to this knot is relevant
-                                knots[index+1][2]# and index + 1 < len(knots) or knots[index + 1][2]
-                                )
+                        def interp_trans(*val):
+                            return coordinate_transformation(*interp(*val))
+                        if self._formatting['family_shape'] == 0:
+                            relative_spline_handles = [(0, 0), (0, 1), (0, 1), (1, 1)]
+                        elif self._formatting['family_shape'] == 1:
+                            relative_spline_handles = [(0, 0), (0, 0.7), (0.5, 0.9), (1, 1)]
+                        else:#if self._formatting['family_shape'] == 2:
+                            relative_spline_handles = [(0, 0), (0.1, 0.3), (0.3, 1), (1, 1)]
+
+                        data.append(
+                            ({'type': 'CubicBezier', 'arguments': (
+                                interp_trans(*relative_spline_handles[0]),
+                                interp_trans(*relative_spline_handles[1]),
+                                interp_trans(*relative_spline_handles[2]),
+                                interp_trans(*relative_spline_handles[3]),
+                            )},
+                                (_birth_position[1], self._map_y_position(
+                                    self._formatting['fade_individual_color_black_age']*365+birth_date_ov)),
+                            # connection to this knot is relevant
+                            knots[index+1][2]# and index + 1 < len(knots) or knots[index + 1][2]
                             )
+                        )
+
                         if self._formatting['individual_photo_active'] and len(gr_individual.individual.images) > 0:
                             svg_path = Path_types[data[-1][0]
                                                   ['type']](*data[-1][0]['arguments'])
-                            for ov, image_dict in gr_individual.individual.images.items():
+                            for ov, image_dict in photo_dict.items():
                                 image_filename = image_dict['filename']
                                 image_size = image_dict['size']
                                 if ov > knots[index][1] and ov < knots[index + 1][1]:
                                     photo_size = self._formatting['individual_photo_relative_size'] * \
-                                        self._formatting['relative_line_thickness'] * \
-                                        self._formatting['horizontal_step_size']
+                                        line_thickness
                                     if type(svg_path) == Line:
                                         xpos = svg_path.start.real + \
                                             self._map_y_position(ov)*1j
@@ -543,20 +557,20 @@ class BaseSVGChart(BaseChart):
                                         coeffs = svg_path.poly()
                                         root = intersection_polynomial(coeffs, self._map_y_position(ov))
                                         xpos = svg_path.point(root)
-                                    images.append(((4, 'layer_photos'), {
-                                            'type': 'image',
-                                            'config': {
-                                                    'insert': (
-                                                        xpos.real - photo_size/2,
-                                                        xpos.imag - photo_size/2),
-                                                    'size': (photo_size, photo_size),
-                                            },
-                                            'filename': image_filename,
-                                            'size': image_size
-                                        }
+                                    gr_individual.items.append((
+                                        (4, 'layer_photos'),
+                                        new_image_item(
+                                            self=self,
+                                            pos_x = xpos.real - photo_size/2,
+                                            pos_y = xpos.imag - photo_size/2,
+                                            size_x = photo_size,
+                                            size_y = photo_size,
+                                            filename = image_filename,
+                                            original_size = image_size
+                                        )
                                     ))
             life_line_bezier_paths = []
-            marriage_bezier(images, life_line_bezier_paths, knots)
+            marriage_bezier(life_line_bezier_paths, knots)
 
             # create item setup
             for path, color_pos, is_cross_connection in life_line_bezier_paths:
@@ -569,12 +583,13 @@ class BaseSVGChart(BaseChart):
                     'config': path,
                     'color': gr_individual.color,
                     'color_pos': color_pos,
-                    'stroke_width': self._formatting['relative_line_thickness']*self._formatting['horizontal_step_size'],
+                    'stroke_width': line_thickness*gr_individual.weight,
                     'gir':gr_individual
                 }))
             if self._formatting['birth_label_active']:
                 if self._formatting['birth_label_along_path']:
-                    gr_individual.items.append(((5, 'layer_birth_label'),
+                    gr_individual.items.append((
+                        (5, 'layer_birth_label'),
                         {
                             'type': 'textPath',
                             'config': {
@@ -599,40 +614,40 @@ class BaseSVGChart(BaseChart):
                     birth_label_text = " ".join(individual_name + [birth_label])
                     if self._formatting['birth_label_wrapping_active']:
                         birth_label_text = birth_label_text.strip().replace(' ', '\n')
-                    gr_individual.items.append(((5, 'layer_birth_label'),{
-                            'type': 'text',
-                            'config': {
-                                'style': f"font-size:{font_size}px;font-family:{self._formatting['font_name']}",
-                                'text': birth_label_text,
-                                'text-anchor': self._formatting['birth_label_anchor'],
-                                'transform': 'rotate(%s,%s, %s)' % (self._formatting['birth_label_rotation']+self._orientation_angle(*_birth_original_location), *_birth_position),
-                                'insert': _birth_position,
-                                'dx': [str(font_size*float(self._formatting['birth_label_letter_x_offset']))],
-                                'dy': [str(float(font_size)/2.7 + font_size*float(self._formatting['birth_label_letter_y_offset']))+'px'],
-                            },
-                            'font_size': font_size,
-                            'font_name': self._formatting['font_name'],
-                        }))
+                    gr_individual.items.append((
+                        (5, 'layer_birth_label'),
+                        new_text_item(
+                            self=self,
+                            text=birth_label_text,
+                            pos_x=_birth_position[0],
+                            pos_y=_birth_position[1],
+                            text_anchor=self._formatting['birth_label_anchor'],
+                            transform=
+                                'rotate(%s,%s, %s)' % (self._formatting['birth_label_rotation']+self._orientation_angle(*_birth_original_location), *_birth_position)
+                                if self._formatting['birth_label_rotation'] != 0 else None,
+                            insert=_birth_position,
+                            dx=[str(font_size*float(self._formatting['birth_label_letter_x_offset']))],
+                            dy=[str(float(font_size)/2.7 + font_size*float(self._formatting['birth_label_letter_y_offset']))+'px'],
+                        )
+                    ))
             if self._formatting['death_label_active']:
                 if self._formatting['death_label_wrapping_active']:
                     death_label = death_label.strip().replace(' ', '\n')
-                gr_individual.items.append(((5, 'layer_death_label'), {
-                        'type': 'text',
-                        'config': {
-                            'style': f"font-size:{font_size}px;font-family:{self._formatting['font_name']}",
-                            'text': death_label,
-                            'text-anchor': self._formatting['death_label_anchor'],
-                            'transform': 'rotate(%g,%s, %s)' % (self._formatting['death_label_rotation']+self._orientation_angle(*_death_original_location), *_death_position),
-                            'insert': _death_position,
-                            'dy': [str(float(font_size)/2.7 + font_size*float(self._formatting['death_label_letter_y_offset']))+'px'],
-                            'dx': [str(font_size*float(self._formatting['death_label_letter_x_offset']))],
-                        },
-                        'font_size': font_size,
-                        'font_name': self._formatting['font_name'],
-
-                    }
+                gr_individual.items.append((
+                    (5, 'layer_death_label'),
+                    new_text_item(
+                        self=self,
+                        text=death_label,
+                        pos_x=_death_position[0],
+                        pos_y=_death_position[1],
+                        text_anchor=self._formatting['death_label_anchor'],
+                        transform=
+                            'rotate(%g,%s, %s)' % (self._formatting['death_label_rotation']+self._orientation_angle(*_death_original_location), *_death_position)
+                            if self._formatting['death_label_rotation'] != 0 else None,
+                        dy=[str(float(font_size)/2.7 + font_size*float(self._formatting['death_label_letter_y_offset']))+'px'],
+                        dx=[str(font_size*float(self._formatting['death_label_letter_x_offset']))],
+                    )
                 ))
-            gr_individual.items += images
             gr_individual.items += debug_items
         if self._formatting['debug_visualize_connections']:
             for gr_family in self.gr_families:
@@ -660,21 +675,16 @@ class BaseSVGChart(BaseChart):
                             marriage_pos_b = calculate_ring_position(gr_other_family)
                             if marriage_pos_b is None:
                                 continue
-                            def coordinate_transformation(x, y):
-                                new_x, new_y = self._map_position(x, y)
-                                return new_x + new_y*1j
 
-                            gr_spouse.items.append(((99, 'layer_debug'),
-                                    {
-                                    'type': 'path',
-                                    'config': {'type': 'Line', 'arguments': (
-                                            coordinate_transformation(*marriage_pos_a),
-                                            coordinate_transformation(*marriage_pos_b)
-                                        )},
-                                    'color': color,
-                                    'stroke_width': thickness
-                                    }
-                                ))
+                            gr_spouse.items.append((
+                                (99, 'layer_debug'),
+                                new_path_item(
+                                    self, 'Line',
+                                    points=[coordinate_transformation(*marriage_pos_a),
+                                            coordinate_transformation(*marriage_pos_b)],
+                                    color=color, stroke_width=thickness
+                                )
+                            ))
 
 
     def paint_and_save(self, filename):
@@ -738,6 +748,9 @@ class BaseSVGChart(BaseChart):
                         constructor_function = Line
                     elif item['config']['type'] == 'CubicBezier':
                         constructor_function = CubicBezier
+                    stroke_dasharray = None
+                    if 'stroke_dasharray' in item:
+                        stroke_dasharray = item['stroke_dasharray']
                     svg_path = Path(constructor_function(*arguments))
 
                     if self._formatting['fade_individual_color'] and 'color_pos' in item:
@@ -745,17 +758,17 @@ class BaseSVGChart(BaseChart):
                             item['color_pos'][0])+""), ("0", str(item['color_pos'][1])+""), gradientUnits='userSpaceOnUse')
                         fill.add_stop_color(
                             0, "rgb({},{},{})".format(*item['color']))
-                        fill.add_stop_color(1, 'black')
+                        fill.add_stop_color(1, "rgb({},{},{})".format(*self._colors['fade_to_death']))
                         # fill.add_stop_color(0, "rgb({},{},{})".format(*item['colors'][1]))
                         # fill.add_stop_color(1, "rgb({},{},{})".format(*item['colors'][0]))
                         svg_document.defs.add(fill)
                         svg_document.add(svg_document.path(d=svg_path.d(), stroke=fill.get_paint_server(
-                            default='currentColor'), fill='none', stroke_width=item['stroke_width']))
+                            default='currentColor'), fill='none', stroke_width=item['stroke_width'], stroke_dasharray=stroke_dasharray))
                     else:
                         # arguments['fill'] = fill
                         # gr_individual.color
                         svg_document.add(svg_document.path(d=svg_path.d(), stroke="rgb({},{},{})".format(
-                            *item['color']), fill='none', stroke_width=item['stroke_width']))
+                            *item['color']), fill='none', stroke_width=item['stroke_width'], stroke_dasharray=stroke_dasharray))
                 elif item['type'] == 'textPath':
                     args_path = item['path']
                     args_text = item['config']
