@@ -1,5 +1,6 @@
 from .BaseFamily import BaseFamily
 from .GedcomParsing import get_date_dict_from_tag, _get_relevant_events, estimate_marriage_date
+from .Exceptions import LifeLineChartNotEnoughInformationToDisplay
 
 
 class GedcomFamily(BaseFamily):
@@ -21,6 +22,9 @@ class GedcomFamily(BaseFamily):
             if 'PLAC' in self._database_fam[self.family_id]['MARR']:
                 self.location = self._database_fam[self.family_id]['MARR']['PLAC']['tag_data']
         estimate_marriage_date(self)
+        if self.marriage is None:
+            raise LifeLineChartNotEnoughInformationToDisplay(
+                "Marriage date is missing "+self.family_id)
 
     def _get_husband_and_wife_id(self):
         """
@@ -51,23 +55,31 @@ class GedcomFamily(BaseFamily):
         except KeyError:
             return []
 
-    def _get_husb_name(self):
+    @property
+    def husb_name(self):
         """
         get the husband name
 
         Returns:
             str: husband name
         """
-        return self._database_indi[self.husband_individual_id]['NAME']['tag_data']
+        try:
+            name = self._database_indi[self.husband_individual_id]['NAME']['tag_data']
+        except KeyError:
+            name = "unknown"
+        return name
 
-    def _get_wife_name(self):
+    @property
+    def wife_name(self):
         """
         get the wife name
 
         Returns:
             str: wife name
         """
-        return self._database_indi[self.wife_individual_id]['NAME']['tag_data']
+        try:
+            name = self._database_indi[self.wife_individual_id]['NAME']['tag_data']
+        except KeyError:
+            name = "unknown"
+        return name
 
-    husb_name = property(_get_husb_name)
-    wife_name = property(_get_wife_name)
